pitchtools.PitchRange
=====================

.. inheritance-diagram:: abjad.tools.pitchtools.PitchRange.PitchRange.PitchRange
   :private-bases:

.. autoclass:: abjad.tools.pitchtools.PitchRange.PitchRange.PitchRange

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.PitchRange.PitchRange.PitchRange.one_line_named_chromatic_pitch_repr

.. autoattribute:: abjad.tools.pitchtools.PitchRange.PitchRange.PitchRange.one_line_numbered_chromatic_pitch_repr

.. autoattribute:: abjad.tools.pitchtools.PitchRange.PitchRange.PitchRange.pitch_range_name

.. autoattribute:: abjad.tools.pitchtools.PitchRange.PitchRange.PitchRange.pitch_range_name_markup

.. autoattribute:: abjad.tools.pitchtools.PitchRange.PitchRange.PitchRange.start_pitch

.. autoattribute:: abjad.tools.pitchtools.PitchRange.PitchRange.PitchRange.start_pitch_is_included_in_range

.. autoattribute:: abjad.tools.pitchtools.PitchRange.PitchRange.PitchRange.stop_pitch

.. autoattribute:: abjad.tools.pitchtools.PitchRange.PitchRange.PitchRange.stop_pitch_is_included_in_range

Special Methods
---------------

.. automethod:: abjad.tools.pitchtools.PitchRange.PitchRange.PitchRange.__contains__

.. automethod:: abjad.tools.pitchtools.PitchRange.PitchRange.PitchRange.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.pitchtools.PitchRange.PitchRange.PitchRange.__eq__

.. automethod:: abjad.tools.pitchtools.PitchRange.PitchRange.PitchRange.__ge__

.. automethod:: abjad.tools.pitchtools.PitchRange.PitchRange.PitchRange.__gt__

.. automethod:: abjad.tools.pitchtools.PitchRange.PitchRange.PitchRange.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.pitchtools.PitchRange.PitchRange.PitchRange.__le__

.. automethod:: abjad.tools.pitchtools.PitchRange.PitchRange.PitchRange.__lt__

.. automethod:: abjad.tools.pitchtools.PitchRange.PitchRange.PitchRange.__ne__

.. automethod:: abjad.tools.pitchtools.PitchRange.PitchRange.PitchRange.__repr__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitchtools.PitchRange.PitchRange.PitchRange.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.pitchtools.PitchRange.PitchRange.PitchRange.__str__

   .. note:: Inherited from `__builtin__.object`
